searchData={"items":[{"type":"module","title":"LiveSvelte","doc":"","ref":"LiveSvelte.html"},{"type":"module","title":"Features - LiveSvelte","doc":"-   ⚡ **End-To-End Reactivity** with LiveView\n-   🔋 **Server-Side Rendered** (SSR) Svelte\n-   🪄 **Sigil** as an [Alternative LiveView DSL](#livesvelte-as-an-alternative-liveview-dsl)\n-   ⭐ **Svelte Preprocessing** Support with [svelte-preprocess](https://github.com/sveltejs/svelte-preprocess)\n-   🦄 **Tailwind** Support\n-   💀 **Dead View** Support\n-   🤏 **live_json** Support\n-   🦥 **Slot Interoperability**","ref":"LiveSvelte.html#module-features"},{"type":"module","title":"Resources - LiveSvelte","doc":"-   [HexDocs](https://hexdocs.pm/live_svelte)\n-   [HexPackage](https://hex.pm/packages/live_svelte)\n-   [Phoenix LiveView](https://github.com/phoenixframework/phoenix_live_view)\n-   [Blog Post](https://wout.space/notes/live-svelte)\n-   [YouTube Introduction](https://www.youtube.com/watch?v=JMkvbW35QvA)","ref":"LiveSvelte.html#module-resources"},{"type":"module","title":"Demo - LiveSvelte","doc":"For a full intro and demo check out the [YouTube introduction](https://www.youtube.com/watch?v=JMkvbW35QvA)\n\n`/examples/advanced_chat`\n\nhttps://user-images.githubusercontent.com/3637265/229902870-29166253-3d18-4b24-bbca-83c4b6648578.webm\n\n \nSvelte handles the look and feel of the chat, while LiveView takes care of syncing. E2E reactivity to the Svelte component so we don't really need to fetch anything! The 'login' to enter your name is a simple LiveView form. Hybrid!\n\n---\n\n`/examples/breaking_news`\n\nhttps://user-images.githubusercontent.com/3637265/229902860-f7ada6b4-4a20-4105-9ee9-79c0cbad8d72.webm\n\n \nNews items are synced with the server while the speed is only client side.","ref":"LiveSvelte.html#module-demo"},{"type":"module","title":"Why LiveSvelte - LiveSvelte","doc":"Phoenix LiveView enables rich, real-time user experiences with server-rendered HTML.\nIt works by communicating any state changes through a websocket and updating the DOM in realtime.\nYou can get a really good user experience without ever needing to write any client side code.\n\nLiveSvelte builds on top of Phoenix LiveView to allow for easy client side state management while still allowing for communication over the websocket.","ref":"LiveSvelte.html#module-why-livesvelte"},{"type":"module","title":"Reasons why you'd use LiveSvelte - LiveSvelte","doc":"-   You have (complex) local state\n-   You want to take full advantage of Javascript's ecosystem\n-   You want to take advantage of Svelte's animations\n-   You want scoped CSS\n-   You like Svelte and its DX :)","ref":"LiveSvelte.html#module-reasons-why-you-d-use-livesvelte"},{"type":"module","title":"Requirements - LiveSvelte","doc":"For Server-Side Rendering (SSR) to work you need `node` (version 19 or later) installed in your environment.\n\nMake sure you have it installed in production too. You might be using `node` in the build step, but it might actually not be installed in your production environment.\n\nYou can make sure you have `node` installed by running `node --version` in your project directory.\n\nIf you don't want SSR, you can disable it by not setting `NodeJS.Supervisor` in `application.ex`. More on that in the [SSR](#ssr-server-side-rendering) section of this document.","ref":"LiveSvelte.html#module-requirements"},{"type":"module","title":"Installation - LiveSvelte","doc":"_If you're updating from an older version, make sure to check the `CHANGELOG.md` for breaking changes._\n\n1. Add `live_svelte` to your list of dependencies of your Phoenix app in `mix.exs`:\n\n```elixir\ndefp deps do\n  [\n    {:live_svelte, \"~> 0.16.0\"}\n  ]\nend\n```\n\n2. Adjust the `setup` and `assets.deploy` aliases in `mix.exs`:\n\n```elixir\ndefp aliases do\n  [\n    setup: [\"deps.get\", \"ecto.setup\", \"cmd --cd assets npm install\"],\n    ...,\n    \"assets.deploy\": [\"tailwind   --minify\", \"cmd --cd assets node build.js --deploy\", \"phx.digest\"]\n  ]\nend\n```\n\nNote: `tailwind   --minify` is only required in the `assets.deploy` alias if you're using Tailwind. If you are not using Tailwind, you can remove it from the list.\n\n3. Run the following in your terminal\n\n```bash\nmix deps.get\nmix live_svelte.setup\n```\n\n4. Add `import LiveSvelte` in `html_helpers/0` inside `/lib/ _web.ex` like so:\n\n```elixir\n# /lib/ _web.ex\n\ndefp html_helpers do\n  quote do\n\n    # ...\n\n    import LiveSvelte  # <-- Add this line\n\n    # ...\n\n  end\nend\n```\n\n5. For tailwind support, add `\"./svelte/**/*.svelte\"` to `content` in the `tailwind.config.js` file\n\n```javascript\n...\ncontent: [\n  ...\n  \"./svelte/**/*.svelte\"\n],\n...\n```\n\n6. Finally, remove the `esbuild` configuration from `config/config.exs` and remove the dependency from the `deps` function in your `mix.exs`, and you are done!","ref":"LiveSvelte.html#module-installation"},{"type":"module","title":"What did we do? - LiveSvelte","doc":"Phoenix's default configuration of esbuild (via the Elixir wrapper) [does not allow you to use esbuild plugins](https://hexdocs.pm/phoenix/asset_management.html#esbuild-plugins). The standard Elixir `esbuild` package works great for simple projects with Phoenix hooks, but to use LiveSvelte we need a more complex setup.\n\nTo use plugins, Phoenix recommends replacing the default build system with a build script. So, in setup, we go from using the standard `esbuild` package to using `esbuild` directly as a `node_module`.\n\nAs a result, you'll notice some related changes:\n\n-   A bunch of files get created in `/assets`.\n-   There are some code changes in `/lib`.\n-   We no longer use the standard Elixir `esbuild` watcher, as we created a new watcher that does the same thing.\n\nThe setup process commented out some lines of code, like configuration in `dev.exs`. It's safe to delete commented-out code if you desire.","ref":"LiveSvelte.html#module-what-did-we-do"},{"type":"module","title":"Usage - LiveSvelte","doc":"Svelte components need to go into the `assets/svelte` directory\n\nAttributes:\n\n-   `name`: Specify the Svelte component\n-   `props` _(Optional)_: Provide the `props` you want to use that should be reactive as a map to the props field\n-   `class` _(Optional)_: Provide `class` to set the class attribute on the root svelte element\n-   `ssr` _(Optional)_: Set `ssr` to `false` to disable server-side rendering\n\ne.g. If your component is named `assets/svelte/Example.svelte`:\n\n```elixir\ndef render(assigns) do\n  ~H\"\"\"\n  <.svelte name=\"Example\" props={%{number: @number}} socket={@socket} />\n  \"\"\"\nend\n```\n\nIf your component is in a directory, for example `assets/svelte/some-directory/SomeComponent.svelte` you need to include the directory in your name: `some-directory/SomeComponent`.","ref":"LiveSvelte.html#module-usage"},{"type":"module","title":"The Components Macro - LiveSvelte","doc":"There is also an Elixir macro which checks your `assets/svelte` folder for any Svelte components, and injects local function `def`s for those components into the calling module.\n\nThis allows for an alternative, more JSX-like authoring experience inside Liveviews.\n\ne.g. in the below example, a Svelte component called `Example` is available to be called inside the Liveview template:\n\n```elixir\nuse LiveSvelte.Components\n\ndef render(assigns) do\n  ~H\"\"\"\n  <.Example number={@number} socket={@socket} />\n  \"\"\"\nend\n```","ref":"LiveSvelte.html#module-the-components-macro"},{"type":"module","title":"Examples - LiveSvelte","doc":"Examples can be found in the `/examples` and `/example_project` directories.\n\nMost of the `/example_project` examples are visible in the [YouTube demo video](https://www.youtube.com/watch?v=JMkvbW35QvA).\n\nI recommend cloning `live_svelte` and running the example project in `/example_project` by running the following commands:\n\n```\ngit clone https://github.com/woutdp/live_svelte.git\nmix assets.build\ncd ./live_svelte/example_project\nnpm install --prefix assets\nmix deps.get\nmix phx.server\n```\n\nServer should be running on `localhost:4000`\n\nIf you have examples you want to add, feel free to create a PR, I'd be happy to add them.\n\n#### Create a Svelte component\n\n```svelte\n \n    // The number prop is reactive,\n    // this means if the server assigns the number, it will update in the frontend\n    export let number = 1\n    // live contains all exported LiveView methods available to the frontend\n    export let live\n\n    function increase() {\n        // This pushes the event over the websocket\n        // The last parameter is optional. It's a callback for when the event is finished.\n        // You could for example set a loading state until the event is finished if it takes a longer time.\n        live.pushEvent(\"set_number\", {number: number + 1}, () => {})\n\n        // Note that we actually never set the number in the frontend!\n        // We ONLY push the event to the server.\n        // This is the E2E reactivity in action!\n        // The number will automatically be updated through the LiveView websocket\n    }\n\n    function decrease() {\n        live.pushEvent(\"set_number\", {number: number - 1}, () => {})\n    }\n \n\n The number is {number} \n + \n - \n```\n\n_Note: that here we use the `pushEvent` function, but you could also use `phx-click` and `phx-value-number` if you wanted._\n\nThe following methods are available on `live`:\n\n-   `pushEvent`\n-   `pushEventTo`\n-   `handleEvent`\n-   `removeHandleEvent`\n-   `upload`\n-   `uploadTo`\n\nThese need to be run on the client, they can't be run in SSR. Either make sure they're called on an action (e.g. clicking a button) or wrap them with `onMount`.\n\nMore about this in the [LiveView documentation on js-interop](https://hexdocs.pm/phoenix_live_view/js-interop.html#client-hooks-via-phx-hook)\n\n#### Create a LiveView\n\n```elixir\n# `/lib/app_web/live/live_svelte.ex`\ndefmodule AppWeb.SvelteLive do\n  use AppWeb, :live_view\n\n  def render(assigns) do\n    ~H\"\"\"\n    <.svelte name=\"Example\" props={%{number: @number}} socket={@socket} />\n    \"\"\"\n  end\n\n  def handle_event(\"set_number\", %{\"number\" => number}, socket) do\n    {:noreply, assign(socket, :number, number)}\n  end\n\n  def mount(_params, _session, socket) do\n    {:ok, assign(socket, :number, 5)}\n  end\nend\n```\n\n```elixir\n# `/lib/app_web/router.ex`\nimport Phoenix.LiveView.Router\n\nscope \"/\", AppWeb do\n  ...\n  live \"/svelte\", SvelteLive\n  ...\nend\n```","ref":"LiveSvelte.html#module-examples"},{"type":"module","title":"LiveSvelte As An Alternative LiveView DSL - LiveSvelte","doc":"[Blogpost on the topic](https://wout.space/notes/live-svelte-as-liveview-dsl)\n\nWe can go one step further and use LiveSvelte as an alternative to the standard LiveView DSL. This idea is inspired by [Surface UI](https://surface-ui.org/).\n\nTake a look at the following example:\n\n```elixir\ndefmodule ExampleWeb.LiveSigil do\n  use ExampleWeb, :live_view\n\n  def render(assigns) do\n    ~V\"\"\"\n     \n      export let number = 5\n      let other = 1\n\n      $: combined = other + number\n     \n\n     This is number: {number} \n     This is other: {other} \n     This is other + number: {combined} \n\n     Increment \n     Increment \n    \"\"\"\n  end\n\n  def mount(_params, _session, socket) do\n    {:ok, assign(socket, :number, 1)}\n  end\n\n  def handle_event(\"increment\", _value, socket) do\n    {:noreply, assign(socket, :number, socket.assigns.number + 1)}\n  end\nend\n```\n\nUse the `~V` sigil instead of `~H` and your LiveView will be Svelte instead of an HEEx template.\n\n#### Installation\n\n1. If it's not already imported inside `html_helpers/0`, add `import LiveSvelte` inside the `live_view` function in your project, this can be found in `/lib/ _web.ex`:\n\n```elixir\ndef live_view do\n  quote do\n    use Phoenix.LiveView,\n      layout: {ExampleWeb.Layouts, :app}\n\n    import LiveSvelte\n\n    unquote(html_helpers())\n  end\nend\n```\n\n2. Ignore build files in your `.gitignore`. The sigil will create Svelte files that are then picked up by `esbuild`, these files don't need to be included in your git repo:\n\n```gitignore\n# Ignore automatically generated Svelte files by the ~V sigil\n/assets/svelte/_build/\n```\n\n#### Neovim Treesitter Config\n\nTo enable syntax highlighting in Neovim with Treesitter, create the following file:\n\n`~/.config/nvim/after/queries/elixir/injections.scm`\n\n```\n; extends\n\n; Svelte\n(sigil\n  (sigil_name) @_sigil_name\n  (quoted_content) @injection.content\n (#eq? @_sigil_name \"V\")\n (#set! injection.language \"svelte\"))\n```\n\nFor Neovim Treesitter version below v0.9:\n\n```\n; extends\n\n; Svelte\n(sigil\n  (sigil_name) @_sigil_name\n  (quoted_content) @svelte\n(#eq? @_sigil_name \"V\"))\n```\n\nAlso make sure Svelte and Elixir is installed in Treesitter.\n\n#### Options\n\nOptions can be passed in the mount by setting `svelte_opts`, check the following example:\n\n```elixir\ndef mount(_params, _session, socket) do\n  {:ok, assign(socket, some_value: 1, svelte_opts: %{ssr: false, class: \"example-class\"})}\nend\n```","ref":"LiveSvelte.html#module-livesvelte-as-an-alternative-liveview-dsl"},{"type":"module","title":"LiveView Live Navigation Events - LiveSvelte","doc":"Inside Svelte you can define [Live Navigation](https://hexdocs.pm/phoenix_live_view/live-navigation.html) links. These links navigate from one LiveView to the other without refreshing the page.\n\nFor example this can be useful when you have a Svelte store and you want this store state to remain during navigation. Example of Svelte store usage can be found in `/examples/store`.\n\n`push_navigate`\n\n```svelte\n Redirect \n```\n\n`push_patch`\n\n```svelte\n Patch \n```","ref":"LiveSvelte.html#module-liveview-live-navigation-events"},{"type":"module","title":"LiveView JavaScript Interoperability - LiveSvelte","doc":"LiveView allows for a bunch of interoperability which you can read more about here:","ref":"LiveSvelte.html#module-liveview-javascript-interoperability"},{"type":"module","title":"Preprocessor - LiveSvelte","doc":"To use the preprocessor, install the desired preprocessor.\n\ne.g. Typescript\n\n```\ncd assets && npm install --save-dev typescript\n```","ref":"LiveSvelte.html#module-preprocessor"},{"type":"module","title":"SSR (Server-Side Rendering) - LiveSvelte","doc":"If you're unfamiliar with SSR (Server-Side Rendering), it is a feature of Svelte to... render Svelte on the server. This means on first page load you get to see HTML instead of a blank page. Immediately after the first page load the page is '[hydrated](https://www.youtube.com/watch?v=D46aT3mx9LU)', which is a fancy word for adding reactivity to your component. This happens in the background, you don't notice this step happening.\n\nThe way LiveSvelte updates itself through LiveView is by letting Svelte handle all the HTML edits. Usually LiveView would edit the HTML by passing messages through the websocket. In our case we only pass the data we provided in the props attribute to Svelte through the websocket. No HTML is being touched by LiveView, Svelte takes care of that.\n\nLike mentioned, without SSR you'd see a brief flash of un-rendered content. Sometimes you can get away with not rendering Svelte on the server, for example when your Svelte component doesn't do any rendering on first page load and needs to be manually toggled for visibility by the user. Or when it is a component that has no visual component to it like tracking your mouse cursor and sending it back to the server.\n\nIn theses cases you can turn off SSR.\n\n#### Disabling SSR\n\nSSR is enabled by default when you install LiveSvelte. If you don't want to use Server-Side Rendering for Svelte, you can disable it in the following ways:\n\n##### Globally\n\nIf you don't want to use SSR on any component you can disable it globally.\n\nThere are 2 ways of doing this\n\n-   Don't include the `NodeJS` supervisor in the `application.ex` file\n    or\n-   Add `ssr: false` to the `live_svelte` config in your `config.exs` file like so:\n\n```elixir\nconfig :live_svelte,\n  ssr: false\n```\n\n##### Component\n\nTo disable SSR on a specific component, set the `ssr` property to false. Like so:\n\n```\n<.svelte name=\"Example\" ssr={false} />\n```","ref":"LiveSvelte.html#module-ssr-server-side-rendering"},{"type":"module","title":"live_json - LiveSvelte","doc":"LiveSvelte has support for [live_json](https://github.com/Miserlou/live_json).\n\nBy default, LiveSvelte sends your entire json object over the wire through LiveView. This can be expensive if your json object is big and changes frequently.\n\n`live_json` on the other hand allows you to only send a _diff_ of the json to Svelte. This is very useful the bigger your json objects get.\n\nCounterintuitively, you don't always want to use `live_json`. Sometimes it's cheaper to send your entire object again. Although diffs are small, they do add a little bit of data to your json. So if your json is relatively small, I'd recommend not using `live_json`, but it's something to experiment with for your use-case.\n\n#### Usage\n\n1. Install [live_json](https://github.com/Miserlou/live_json#installation)\n\n2. Use `live_json` in your project with LiveSvelte. For example:\n\n```elixir\ndef render(assigns) do\n  ~H\"\"\"\n    <.svelte name=\"Component\" live_json_props={%{my_prop: @ljmy_prop}} socket={@socket} />\n  \"\"\"\nend\n\ndef mount(_, _, socket) do\n  # Get `my_big_json_object` somehow\n  {:ok, LiveJson.initialize(\"my_prop\", my_big_json_object)}\nend\n\ndef handle_info(%Broadcast{event: \"update\", payload: my_big_json_object}, socket) do\n  {:noreply, LiveJson.push_patch(socket, \"my_prop\", my_big_json_object)}\nend\n```\n\n#### Example\n\nYou can find an example [here](https://github.com/woutdp/live_svelte/blob/master/example_project/lib/example_web/live/live_json.ex).","ref":"LiveSvelte.html#module-live_json"},{"type":"module","title":"Structs and Ecto - LiveSvelte","doc":"We use [Jason](https://github.com/michalmuskala/jason) to serialize any data you pass in the props so it can be handled by Javascript.\nJason doesn't know how to handle structs by default, so you need to define it yourself.\n\n#### Structs\n\nFor example, if you have a regular struct like this:\n\n```elixir\ndefmodule User do\n  defstruct name: \"John\", age: 27, address: \"Main St\"\nend\n```\n\nYou must define `@derive`\n\n```elixir\ndefmodule User do\n  @derive Jason.Encoder\n  defstruct name: \"John\", age: 27, address: \"Main St\"\nend\n```\n\nBe careful though, as you might accidentally leak certain fields you don't want the client to access, you can include which fields to serialize:\n\n```elixir\ndefmodule User do\n  @derive {Jason.Encoder, only: [:name, :age]}\n  defstruct name: \"John\", age: 27, address: \"Main St\"\nend\n```\n\n#### Ecto\n\nIn ecto's case it's important to _also_ omit the `__meta__` field as it's not serializable.\n\nCheck out the following example:\n\n```elixir\ndefmodule Example.Planets.Planet do\n  use Ecto.Schema\n  import Ecto.Changeset\n  @derive {Jason.Encoder, except: [:__meta__]}\n\n  schema \"planets\" do\n    field :diameter, :integer\n    field :mass, :integer\n    field :name, :string\n\n    timestamps()\n  end\n\n  ...\nend\n```\n\n#### Documentation\n\nMore documentation on the topic:\n\n-   [HexDocs](https://hexdocs.pm/jason/Jason.Encoder.html)\n-   [GitHub](https://github.com/michalmuskala/jason#encoders)","ref":"LiveSvelte.html#module-structs-and-ecto"},{"type":"module","title":"Slots - LiveSvelte","doc":"You can slot Elixir inside a LiveSvelte component like so:\n\n```elixir\n<.svelte name=\"Example\">\n   Slot content \n</.svelte>\n```\n\nAnd in the Svelte file it will look like this:\n\n```svelte\n \n    let {children}: = $props()\n \n\n Opening \n  {@render children?.()}\n Closing \n```\n\nNamed slots also work:\n\n```elixir\n<.svelte name=\"Example\">\n  Main content\n  <:subtitle>\n     Slot content \n  </:subtitle>\n</.svelte>\n```\n\n```svelte\n \n    let {children, subtitle}: = $props()\n \n\n Opening \n  {@render children()}\n   {@render subtitle()} \n Closing \n```\n\nThis works because of the Snippet API provided by Svelte. Be careful though, it's a new feature that might not be working 100% of the time, I'd love to see what limitations you hit with it. One limitation is that you can't slot other Svelte components.","ref":"LiveSvelte.html#module-slots"},{"type":"module","title":"Showing fallback content with :loading - LiveSvelte","doc":"When SSR is disabled, a full‑page refresh briefly shows a blank content before Svelte finishes loading.\nUse the `:loading` slot to render a placeholder during that gap:\n\n```elixir\n<.svelte name=\"Example\" ssr={false}>\n  <:loading>\n     Until your LiveSvelte component renders client-side, this will be displayed \n  </:loading>\n</.svelte>\n```","ref":"LiveSvelte.html#module-showing-fallback-content-with-loading"},{"type":"module","title":"Caveats - LiveSvelte","doc":"### \"Secret State\"\n\nWith LiveView, it's easy to keep things secret. Let's say you have a conditional that only renders when something is `true`, in LiveView there's no way to know what that conditional will show until it is shown, that's because the HTML is sent over the wire.\n\nWith LiveSvelte, we're dealing with JSON being sent to Svelte, which in turn takes that JSON data and conditionally renders something, even if we don't set the conditional to `true`, the Svelte code will contain code on what to show when the conditional turns `true`.\n\nIn a lot of scenarios this is not an issue, but it can be and is something you should be aware of.","ref":"LiveSvelte.html#module-caveats"},{"type":"module","title":"LiveSvelte Development - LiveSvelte","doc":"","ref":"LiveSvelte.html#module-livesvelte-development"},{"type":"module","title":"Local Setup - LiveSvelte","doc":"#### Example Project\n\nYou can use `/example_project` as a way to test `live_svelte` locally.\n\n#### Custom Project\n\nYou can also use your own project.\n\nClone `live_svelte` to the parent directory of the project you want to test it in.\n\nInside `mix.exs`\n\n```elixir\n{:live_svelte, path: \"../live_svelte\"},\n```\n\nInside `assets/package.json`\n\n```javascript\n\"live_svelte\": \"file:../../live_svelte\",\n```","ref":"LiveSvelte.html#module-local-setup"},{"type":"module","title":"Building Static Files - LiveSvelte","doc":"Make the changes in `/assets/js` and run:\n\n```bash\nmix assets.build\n```\n\nOr run the watcher:\n\n```bash\nmix assets.build --watch\n```","ref":"LiveSvelte.html#module-building-static-files"},{"type":"module","title":"Releasing - LiveSvelte","doc":"-   Make sure you've built the latest assets with `mix assets.build`\n-   Update the version in `README.md`\n-   Update the version in `package.json`\n-   Update the version in `mix.exs`\n-   Update the changelog\n\nRun:\n\n```bash\nmix hex.publish\n```\n\n-   Publish a tag for the latest version","ref":"LiveSvelte.html#module-releasing"},{"type":"module","title":"Deployment - LiveSvelte","doc":"Deploying a LiveSvelte app is the same as deploying a regular Phoenix app, except that you will need to ensure that `nodejs` (version 19 or later) is installed in your production environment.\n\nThe below guide shows how to deploy a LiveSvelte app to [Fly.io](https://fly.io/), but similar steps can be taken to deploy to other hosting providers.\nYou can find more information on how to deploy a Phoenix app [here](https://hexdocs.pm/phoenix/deployment.html).","ref":"LiveSvelte.html#module-deployment"},{"type":"module","title":"Deploying on Fly.io - LiveSvelte","doc":"The following steps are needed to deploy to Fly.io. This guide assumes that you'll be using Fly Postgres as your database. Further guidance on how to deploy to Fly.io can be found [here](https://fly.io/docs/elixir/getting-started/).\n\n1. Generate a `Dockerfile`:\n\n```bash\nmix phx.gen.release --docker\n```\n\n2. Modify the generated `Dockerfile` to install `curl`, which is used to install `nodejs` (version 19 or greater), and also add a step to install our `npm` dependencies:\n\n```diff\n# ./Dockerfile\n\n...\n\n# install build dependencies\n- RUN apt-get update -y && apt-get install -y build-essential git \\\n+ RUN apt-get update -y && apt-get install -y build-essential git curl \\\n    && apt-get clean && rm -f /var/lib/apt/lists/*_*\n\n+ # install nodejs for build stage\n+ RUN curl -fsSL https://deb.nodesource.com/setup_19.x | bash - && apt-get install -y nodejs\n\n...\n\nCOPY assets assets\n\n+ # install all npm packages in assets directory\n+ WORKDIR /app/assets\n+ RUN npm install\n\n+ # change back to build dir\n+ WORKDIR /app\n\n...\n\n# start a new build stage so that the final image will only contain\n# the compiled release and other runtime necessities\nFROM ${RUNNER_IMAGE}\n\nRUN apt-get update -y && \\\n-  apt-get install -y libstdc++6 openssl libncurses5 locales ca-certificates \\\n+  apt-get install -y libstdc++6 openssl libncurses5 locales ca-certificates curl \\\n   && apt-get clean && rm -f /var/lib/apt/lists/*_*\n\n+ # install nodejs for production environment\n+ RUN curl -fsSL https://deb.nodesource.com/setup_19.x | bash - && apt-get install -y nodejs\n\n...\n```\n\nNote: `nodejs` is installed BOTH in the build stage and in the final image. This is because we need `nodejs` to install our `npm` dependencies and also need it when running our app.\n\n3. Launch your app with the Fly.io CLI:\n\n```bash\nfly launch\n```\n\n4. When prompted to tweak settings, choose `y`:\n\n```bash\n? Do you want to tweak these settings before proceeding? (y/N) y\n```\n\nThis will launch a new window where you can tweak your launch settings. In the database section, choose `Fly Postgres` and enter a name for your database. You may also want to change your database to the development configuration to avoid extra costs. You can leave the rest of the settings as-is unless you want to change them.\n\nDeployment will continue once you hit confirm.\n\n5. Once the deployment completes, run the following command to see your deployed app!\n\n```bash\nfly apps open\n```","ref":"LiveSvelte.html#module-deploying-on-fly-io"},{"type":"module","title":"Svelte 4 -> Svelte 5 migration guide - LiveSvelte","doc":"Since version `0.15.0`, LiveSvelte supports Svelte 5. If you want to use Svelte 4, use version `0.14.0`. Note that Svelte 5 is backwards compatible with Svelte 4 for the most part, so even if you're using Svelte 4 syntax, with the latest version it should still work, and so there should be few reasons why to stay on version `0.14.0`.\n\nTo migrate your project from `0.14.0` to `0.15.0` you need to follow the following 3 steps:\n\n1. Update `mix.exs` and run `mix deps.get`\n\n```elixir\n# `mix.exs`\n{:live_svelte, \"0.15.0\"}`\n```\n\n2. Update to the latest Svelte 5 and `esbuild-svelte` version in your package.json\n\n```javascript\n  // package.json\n \"esbuild-svelte\": \"^0.9.0\",\n \"svelte\": \"^5\",\n```\n\n3. Update your build.js file.\nWhich you can find [here](https://github.com/woutdp/live_svelte/blob/master/assets/copy/build.js)","ref":"LiveSvelte.html#module-svelte-4-svelte-5-migration-guide"},{"type":"module","title":"Credits - LiveSvelte","doc":"-   [Ryan Cooke](https://dev.to/debussyman) - [E2E Reactivity using Svelte with Phoenix LiveView](https://dev.to/debussyman/e2e-reactivity-using-svelte-with-phoenix-liveview-38mf)\n-   [Svonix](https://github.com/nikokozak/svonix)\n-   [Sveltex](https://github.com/virkillz/sveltex)","ref":"LiveSvelte.html#module-credits"},{"type":"module","title":"Alternatives for other frontend frameworks - LiveSvelte","doc":"-   Vue: [LiveVue](https://github.com/Valian/live_vue)\n-   React: [LiveReact](https://github.com/mrdotb/live_react)","ref":"LiveSvelte.html#module-alternatives-for-other-frontend-frameworks"},{"type":"module","title":"LiveSvelte Projects - LiveSvelte","doc":"-   [ash-svelte-flowbite](https://github.com/dev-guy/ash-svelte-flowbite)\n-   [Local-First Todo App](https://github.com/tonydangblog/liveview-svelte-pwa)\n-   [Beacon LiveAdmin](https://github.com/BeaconCMS/beacon_live_admin)\n-   [TV Labs](https://tvlabs.ai/)\n\n_Using LiveSvelte in a public project? Let me know and I'll add it to this list!_","ref":"LiveSvelte.html#module-livesvelte-projects"},{"type":"function","title":"LiveSvelte.render/1","doc":"","ref":"LiveSvelte.html#render/1"},{"type":"function","title":"LiveSvelte.svelte/1","doc":"Renders a Svelte component on the server.","ref":"LiveSvelte.html#svelte/1"},{"type":"function","title":"Attributes - LiveSvelte.svelte/1","doc":"* `props` (`:map`) - Props to pass to the Svelte component. Defaults to `%{}`.\n* `name` (`:string`) (required) - Name of the Svelte component.Examples include `\"YourComponent\"`, and `\"directory/Example\"`.\n* `class` (`:string`) - Class to apply to the Svelte component. Defaults to `nil`.\n* `ssr` (`:boolean`) - Whether to render the component via NodeJS on the server. Defaults to `true`.\n* `socket` (`:map`) - LiveView socket, only needed when ssr: true. Defaults to `nil`.\n* `live_json_props` (`:map`) - LiveJson props to pass to the Svelte component. Defaults to `%{}`.","ref":"LiveSvelte.html#svelte/1-attributes"},{"type":"function","title":"Slots - LiveSvelte.svelte/1","doc":"* `inner_block` - Inner block of the Svelte component.\n* `loading` - LiveView rendered markup to show while the component is loading client-side.","ref":"LiveSvelte.html#svelte/1-slots"},{"type":"module","title":"LiveSvelte.Components","doc":"Macros to improve the developer experience of crossing the Liveview/Svelte boundary.","ref":"LiveSvelte.Components.html"},{"type":"macro","title":"LiveSvelte.Components.__using__/1","doc":"Generates functions local to your current module that can be used to render Svelte components.","ref":"LiveSvelte.Components.html#__using__/1"},{"type":"function","title":"LiveSvelte.Components.get_svelte_components/0","doc":"TODO: This could perhaps be optimized to only read the files once per compilation.","ref":"LiveSvelte.Components.html#get_svelte_components/0"},{"type":"module","title":"LiveSvelte.LiveJson","doc":"","ref":"LiveSvelte.LiveJson.html"},{"type":"function","title":"LiveSvelte.LiveJson.live_json/1","doc":"","ref":"LiveSvelte.LiveJson.html#live_json/1"},{"type":"function","title":"Attributes - LiveSvelte.LiveJson.live_json/1","doc":"* `live_json_props` (`:map`) - LiveJSON props to pass to the svelte component. Defaults to `%{}`.","ref":"LiveSvelte.LiveJson.html#live_json/1-attributes"},{"type":"function","title":"Slots - LiveSvelte.LiveJson.live_json/1","doc":"* `inner_block`","ref":"LiveSvelte.LiveJson.html#live_json/1-slots"},{"type":"behaviour","title":"LiveSvelte.SSR","doc":"A behaviour for rendering Svelte components server-side.\n\nTo define a custom renderer, change the application config in `config.exs`:\n\n    config :live_svelte, ssr_module: MyCustomSSRModule","ref":"LiveSvelte.SSR.html"},{"type":"type","title":"LiveSvelte.SSR.component_name/0","doc":"","ref":"LiveSvelte.SSR.html#t:component_name/0"},{"type":"type","title":"LiveSvelte.SSR.props/0","doc":"","ref":"LiveSvelte.SSR.html#t:props/0"},{"type":"function","title":"LiveSvelte.SSR.render/3","doc":"","ref":"LiveSvelte.SSR.html#render/3"},{"type":"callback","title":"LiveSvelte.SSR.render/3","doc":"","ref":"LiveSvelte.SSR.html#c:render/3"},{"type":"type","title":"LiveSvelte.SSR.render_response/0","doc":"A render response which should take the shape:\n    %{\n      \"css\" => %{\n        \"code\" => String.t | nil,\n        \"map\" => String.t | nil\n      },\n      \"head\" => String.t,\n      \"html\" => String.t\n    }","ref":"LiveSvelte.SSR.html#t:render_response/0"},{"type":"function","title":"LiveSvelte.SSR.server_path/0","doc":"","ref":"LiveSvelte.SSR.html#server_path/0"},{"type":"type","title":"LiveSvelte.SSR.slots/0","doc":"","ref":"LiveSvelte.SSR.html#t:slots/0"},{"type":"task","title":"mix live_svelte.configure_esbuild","doc":"Creates Javascript files to be used by esbuild. Necessary for LiveSvelte to work.","ref":"Mix.Tasks.LiveSvelte.ConfigureEsbuild.html"},{"type":"function","title":"Mix.Tasks.LiveSvelte.ConfigureEsbuild.run/1","doc":"","ref":"Mix.Tasks.LiveSvelte.ConfigureEsbuild.html#run/1"},{"type":"task","title":"mix live_svelte.configure_phoenix","doc":"Configures any necessary code changes inside Phoenix to make LiveSvelte work.","ref":"Mix.Tasks.LiveSvelte.ConfigurePhoenix.html"},{"type":"function","title":"Mix.Tasks.LiveSvelte.ConfigurePhoenix.run/1","doc":"","ref":"Mix.Tasks.LiveSvelte.ConfigurePhoenix.html#run/1"},{"type":"task","title":"mix live_svelte.install_npm_deps","doc":"Installs npm dependencies for LiveSvelte.","ref":"Mix.Tasks.LiveSvelte.InstallNpmDeps.html"},{"type":"function","title":"Mix.Tasks.LiveSvelte.InstallNpmDeps.run/1","doc":"","ref":"Mix.Tasks.LiveSvelte.InstallNpmDeps.html#run/1"},{"type":"task","title":"mix live_svelte.setup","doc":"Runs all setup tasks for LiveSvelte.","ref":"Mix.Tasks.LiveSvelte.Setup.html"},{"type":"function","title":"Mix.Tasks.LiveSvelte.Setup.run/1","doc":"","ref":"Mix.Tasks.LiveSvelte.Setup.html#run/1"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}